@@ -4,9 +4,6 @@ import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
 
-import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionDialog;
-import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionListener;
-import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowsProperties;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
@@ -16,6 +13,9 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.DimensionRow;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.rows.EditRowSession;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
+import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionDialog;
+import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionListener;
+import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowsProperties;
 import org.gcube.portlets.user.td.tablewidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.tablewidget.client.util.UtilsGXT3;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
@@ -24,6 +24,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableReque
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableWhy;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.CellData;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.OperationResult;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.grid.model.RowRaw;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
@@ -82,6 +83,7 @@ public class EditRowPanel extends FramedPanel implements MonitorDialogListener {
 	private static final String HEIGHT = "370px";
 	private static final String CONTAINERHEIGHT = "370px";
 	private static final int LABELSIZE = 120;
+	private static final int LABEL_SIZE_IN_CHAR = 17;
 	private static final String FIELDSETWIDTH = "640px";
 
 	private EditRowDialog parent;
@@ -159,7 +161,7 @@ public class EditRowPanel extends FramedPanel implements MonitorDialogListener {
 
 		v = new VerticalLayoutContainer();
 		v.setScrollMode(ScrollMode.AUTO);
-		v.setAdjustForScroll(false);
+		v.setAdjustForScroll(true);
 
 		btnSave = new TextButton("Save");
 		btnSave.setIcon(ResourceBundle.INSTANCE.save());
@@ -239,11 +241,10 @@ public class EditRowPanel extends FramedPanel implements MonitorDialogListener {
 				fieldSetLayout.add(fl, new VerticalLayoutData(1, -1,
 						new Margins(0)));
 			}
-			
 
 			v.add(fieldSet, new VerticalLayoutData(1, -1, new Margins(1)));
 		}
-		
+
 		container.add(v, new MarginData(0));
 		container.forceLayout();
 
@@ -292,9 +293,9 @@ public class EditRowPanel extends FramedPanel implements MonitorDialogListener {
 			String label = new String();
 			if (col != null && col.getLabel() != null) {
 				label = SafeHtmlUtils.htmlEscape(col.getLabel());
-				if (label.length() > LABELSIZE - 1) {
-					label = label.substring(0, LABELSIZE - 3);
-					label += "..";
+				if (label.length() > LABEL_SIZE_IN_CHAR + 2) {
+					label = label.substring(0, LABEL_SIZE_IN_CHAR);
+					label += "...";
 				}
 			}
 			if (!col.isViewColumn()) {
@@ -783,10 +784,10 @@ public class EditRowPanel extends FramedPanel implements MonitorDialogListener {
 	}
 
 	@Override
-	public void operationComplete(TRId trId) {
+	public void operationComplete(OperationResult operationResult) {
 		ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.EDITROW, trId, why);
+				ChangeTableRequestType.EDITROW, operationResult.getTrId(), why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
 	}
@@ -799,10 +800,11 @@ public class EditRowPanel extends FramedPanel implements MonitorDialogListener {
 	}
 
 	@Override
-	public void operationStopped(TRId trId, String reason, String details) {
+	public void operationStopped(OperationResult operationResult,
+			String reason, String details) {
 		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.EDITROW, trId, why);
+				ChangeTableRequestType.EDITROW, operationResult.getTrId(), why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
 
